;; Generated package description from denote-org.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "denote-org" "0.1.1.0.20250731.60858" "Denote extensions for Org mode" '((emacs "28.1") (denote "4.0.0")) :commit "7873643ac5541e0137e05fbab7c20f788ecd24be" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote-org")
